==> maDB_1.4.0.tar.gz: maDB/man/SignalChannel-class.Rd <==
\name{SignalChannel-class}
\docType{class}
\alias{SignalChannel-class}
\alias{createNewDBTable,SignalChannel-method}
\alias{getContentMatrix,SignalChannel-method}
\alias{show,SignalChannel-method}

\title{Micro array signal channel description}
\description{With this object it is possible to describe the signal channels of a micro array experiment. This object establishes the linkage between the sample that was hybridized onto a micro array and the signal channel that was used for this sample. It is therefore possible to use the same type of object (namely the \code{EexprSet} object) with both one signal channel arrays like Affymetrix and two or more signal channel micro arrays.}
\section{Slots}{
  \describe{
    \item{\code{hyb.date}:}{The date when the sample was hybridized onto the  array.}
    \item{\code{label.date}:}{The date when the sample was labeled.}
    \item{\code{label.incorporation}:}{The method that was used to label the RNA.}
    \item{\code{color}:}{A description of the color that was used.}
    \item{\code{description}:}{A description.}
    \item{\code{array.index}:}{The index of the corresponding array in the \code{EexprSet} object.}
    \item{\code{sample.index}:}{The index of the corresponding sample in the \code{samples} slot of the \code{EexprSet} object.}
    \item{\code{array.name}:}{The micro array name or ID.}
  }
}
\section{Methods}{
  \describe{
    \item{createNewDBTable}{\code{signature(object = "SignalChannel")}: creates a new database table that can be used to store objects from the type \code{SignalChannel} into. }
    \item{getContentMatrix}{\code{signature(object = "SignalChannel")}: returns the content of the slots of the \code{SignalChannel} object as a character matrix. }
    \item{show}{\code{signature(object = "SignalChannel")}: Displays the objects content. }
  }
}
\references{}
\author{Johannes Rainer}

\seealso{
  \code{\link{EexprSet-class}},
  \code{\link{Sample-class}},
  \code{\link{loadFromDB}},
  \code{\link{publishToDB}},
  \code{\link{getSignalChannels}}
  \code{\link{getArrays}}
}
\examples{
}
\keyword{classes}

==> maDB_1.12.0.tar.gz: maDB/man/SignalChannel-class.Rd <==
\name{SignalChannel-class}
\docType{class}
\alias{SignalChannel-class}
\alias{createNewDBTable,SignalChannel-method}
\alias{getContentMatrix,SignalChannel-method}
\alias{show,SignalChannel-method}

\title{Microarray signal channel description}
\description{With this object it is possible to describe the signal channels of a microarray experiment. This object establishes the linkage between the sample that was hybridized onto a specific signal channel of a microarray (signal channels correspond to the columns of the \code{exprs} slot of a \code{MadbSet} (or \code{ExpressionSet})).
\\
For further informations and examples refer to the package vignette (which can be opened using the \code{\link{openMadbVignette}}).
}
\section{Slots}{
  \describe{
    \item{\code{hyb.date}:}{The date when the sample was hybridized onto the  array.}
    \item{\code{label.date}:}{The date when the sample was labeled.}
    \item{\code{label.incorporation}:}{The method that was used to label the RNA.}
    \item{\code{color}:}{A description of the color that was used.}
    \item{\code{description}:}{A description.}
    \item{\code{array.index}:}{The index of the corresponding array in the \code{MadbSet} object.}
    \item{\code{sample.index}:}{The index of the corresponding sample in the \code{samples} slot of the \code{MadbSet} object.}
    \item{\code{array.name}:}{The micro array name or ID.}
  }
}
\section{Methods}{
  \describe{
    \item{createNewDBTable}{\code{signature(object = "SignalChannel")}: creates a new database table that can be used to store objects from the type \code{SignalChannel} into. }
    \item{getContentMatrix}{\code{signature(object = "SignalChannel")}: returns the content of the slots of the \code{SignalChannel} object as a character matrix. }
    \item{show}{\code{signature(object = "SignalChannel")}: Displays the objects content. }
  }
}
\references{}
\author{Johannes Rainer}

\seealso{
  \code{\link{MadbSet-class}},
  \code{\link{Sample-class}},
  \code{\link{loadFromDB}},
  \code{\link{publishToDB}},
  \code{\link{getSignalChannels}}
  \code{\link{getArrays}}
}
\examples{
}
\keyword{classes}
